@@ -3,11 +3,12 @@
 #' Computes the genotype probability distribution of one or several pedigree
 #' members, possibly conditional on known genotypes for the marker.
 #'
-#' @param x A `ped` object.
+#' @param x A `ped` object or a list of such.
 #' @param ids A numeric with ID labels of one or more pedigree members.
 #' @param partialmarker Either a `marker` object or the name (or index) of a
-#'   marker attached to `x`.
-#' @param loop_breakers (Only relevant if the pedigree has loops). A vector with
+#'   marker attached to `x`. If `x` has multiple components, only the latter is
+#'   allowed.
+#' @param loopBreakers (Only relevant if the pedigree has loops). A vector with
 #'   ID labels of individuals to be used as loop breakers. If NULL (default)
 #'   loop breakers are selected automatically. See [breakLoops()].
 #' @param eliminate A non-negative integer, indicating the number of iterations
@@ -21,6 +22,7 @@
 #'   alleles for the marker. If the entry in column `j` is the integer `k`, this
 #'   means that the genotype of individual `ids[j]` is row `k` of `M`.
 #' @param verbose A logical.
+#'
 #' @return A named `k`-dimensional array, where `k = length(ids)`, with the
 #'   joint genotype distribution for the `ids` individuals. The probabilities
 #'   are conditional on the known genotypes and the allele frequencies of
@@ -36,30 +38,43 @@
 #' oneMarkerDistribution(s, ids = 1, partialmarker = m)
 #'
 #' # Conditioning on a partial genotype
-#' genotype(m, id = 1) = c(1, NA)
+#' genotype(m, id = 1) = "1/-"
 #' oneMarkerDistribution(s, ids = 1, partialmarker = m)
 #'
 #' # Genotype distribution for a child of heterozygous parents
 #' trio = nuclearPed(father = "fa", mother = "mo", child = "ch")
-#' m1 = marker(trio, fa = 1:2, mo = 1:2)
+#' m1 = marker(trio, fa = "1/2", mo = "1/2")
 #' oneMarkerDistribution(trio, ids = "ch", partialmarker = m1)
 #'
 #' # Joint distribution of the parents, given that the child is heterozygous
-#' m2 = marker(trio, ch = 1:2, alleles = 1:2, afreq = c(0.5, 0.5))
+#' m2 = marker(trio, ch = "1/2", afreq = c("1" = 0.5, "2" = 0.5))
 #' oneMarkerDistribution(trio, ids = c("fa", "mo"), partialmarker = m2)
 #'
 #' # A different example: The genotype distribution of an individual (id = 8)
 #' # whose half cousin (id = 9) is homozygous for a rare allele.
-#' y = halfCousinPed(degree = 1)
-#' snp = marker(y, `9` = "a", alleles = c("a", "b"), afreq = c(0.01, 0.99))
-#' plot(y, snp)
-#' oneMarkerDistribution(y, ids = 8, partialmarker = snp)
+#' y = halfCousinPed(degree = 1) |>
+#'   addMarker("9" = "a/a", afreq = c(a = 0.01, b = 0.99))
+#'
+#' oneMarkerDistribution(y, ids = 8, partialmarker = 1)
 #'
 #' @export
-oneMarkerDistribution = function(x, ids, partialmarker, loop_breakers = NULL,
+oneMarkerDistribution = function(x, ids, partialmarker, loopBreakers = NULL,
                                  eliminate = 0, grid.subset = NULL, verbose = TRUE) {
+
+  if(is.pedList(x)) {
+    if(is.marker(partialmarker))
+      stop2("When `x` has multiple components, `partialmarker` cannot be an unattached marker object")
+
+    pednr = getComponent(x, ids, checkUnique = TRUE)
+    if(all(pednr == pednr[1]))
+      x = x[[pednr[1]]]
+    else
+      stop2("Individuals from different pedigree components are not implemented yet")
+  }
+
   if(!is.ped(x))
-    stop2("Input is not a `ped` object")
+    stop2("Input is not a pedigree")
+
   if(!isCount(eliminate, minimum = 0))
     stop2("`eliminate` must be a nonnegative integer")
 
@@ -93,7 +108,7 @@ oneMarkerDistribution = function(x, ids, partialmarker, loop_breakers = NULL,
     grid.subset = as.matrix(grid.subset)
 
   if (x$UNBROKEN_LOOPS) {
-    x = breakLoops(setMarkers(x, m), loopBreakers = loop_breakers, verbose = verbose)
+    x = breakLoops(setMarkers(x, m), loopBreakers = loopBreakers, verbose = verbose)
     m = x$MARKERS[[1]]
   }
 
